=== modified file 'drizzled/identifier/catalog.cc'
--- drizzled/identifier/catalog.cc	2010-12-03 04:10:23 +0000
+++ drizzled/identifier/catalog.cc	2011-01-01 01:13:51 +0000
@@ -44,12 +44,12 @@
 namespace identifier
 {
 
-static void build_schema_filename(string &path, const string &name)
+static void build_schema_filename(string &path, const string &name_arg)
 {
   path.append("../");
   bool conversion_error= false;
 
-  conversion_error= util::tablename_to_filename(name, path);
+  conversion_error= util::tablename_to_filename(name_arg, path);
   if (conversion_error)
   {
     errmsg_printf(ERRMSG_LVL_ERROR,
@@ -59,11 +59,11 @@
 }
 
 Catalog::Catalog(const std::string &name_arg) :
-  name(name_arg)
+  _name(name_arg)
 { 
   assert(not name_arg.empty());
 
-  build_schema_filename(path, name);
+  build_schema_filename(path, _name);
   assert(path.length()); // TODO throw exception, this is a possibility
 
   util::insensitive_hash hasher;
@@ -77,33 +77,33 @@
 
 bool Catalog::compare(const std::string &arg) const
 {
-  return boost::iequals(arg, name);
+  return boost::iequals(arg, _name);
 }
 
 bool Catalog::isValid() const
 {
-  if (name.empty())
-    return false;
-
-  if (name.size() > NAME_LEN)
-    return false;
-
-  if (name.at(name.length() -1) == ' ')
+  if (_name.empty())
+    return false;
+
+  if (_name.size() > NAME_LEN)
+    return false;
+
+  if (_name.at(_name.length() -1) == ' ')
     return false;
 
   const CHARSET_INFO * const cs= &my_charset_utf8mb4_general_ci;
 
   int well_formed_error;
-  uint32_t res= cs->cset->well_formed_len(cs, name.c_str(), name.c_str() + name.length(),
+  uint32_t res= cs->cset->well_formed_len(cs, _name.c_str(), _name.c_str() + _name.length(),
                                           NAME_CHAR_LEN, &well_formed_error);
 
   if (well_formed_error)
   {
-    my_error(ER_INVALID_CHARACTER_STRING, MYF(0), "identifier", name.c_str());
+    my_error(ER_INVALID_CHARACTER_STRING, MYF(0), "identifier", _name.c_str());
     return false;
   }
 
-  if (name.length() != res)
+  if (_name.length() != res)
     return false;
 
   return true;

=== modified file 'drizzled/identifier/catalog.h'
--- drizzled/identifier/catalog.h	2010-12-30 08:27:31 +0000
+++ drizzled/identifier/catalog.h	2011-01-01 01:13:51 +0000
@@ -41,7 +41,7 @@
 
 class Catalog
 {
-  std::string name;
+  std::string _name;
   std::string path;
 
 
@@ -63,7 +63,12 @@
 
   const std::string &getName() const
   {
-    return name;
+    return _name;
+  }
+
+  const std::string &name() const
+  {
+    return _name;
   }
 
   bool isValid() const;

=== modified file 'drizzled/identifier/schema.cc'
--- drizzled/identifier/schema.cc	2010-12-18 18:24:57 +0000
+++ drizzled/identifier/schema.cc	2011-01-01 01:13:51 +0000
@@ -63,8 +63,7 @@
 
 SchemaIdentifier::SchemaIdentifier(const std::string &db_arg) :
   db(db_arg),
-  db_path(""),
-  catalog("LOCAL")
+  db_path("")
 { 
 #if 0
   string::size_type lastPos= db.find_first_of('/', 0);

=== modified file 'drizzled/identifier/schema.h'
--- drizzled/identifier/schema.h	2010-12-29 20:26:03 +0000
+++ drizzled/identifier/schema.h	2011-01-01 01:13:51 +0000
@@ -35,6 +35,7 @@
 #include <drizzled/enum.h>
 #include "drizzled/definitions.h"
 #include "drizzled/message/table.pb.h"
+#include "drizzled/catalog/local.h"
 #include <string.h>
 
 #include <assert.h>
@@ -49,13 +50,10 @@
 
 namespace drizzled {
 
-static std::string default_catalog("local");
-
 class SchemaIdentifier
 {
   std::string db;
   std::string db_path;
-  std::string catalog;
 
 public:
   typedef std::vector <SchemaIdentifier> vector;
@@ -76,7 +74,7 @@
 
   const std::string &getCatalogName() const
   {
-    return catalog;
+    return drizzled::catalog::local_identifier().name();
   }
 
   virtual bool isValid() const;
@@ -93,7 +91,7 @@
                                   SchemaIdentifier::const_reference identifier)
   {
     output << "SchemaIdentifier:(";
-    output <<  identifier.catalog;
+    output <<  catalog::local_identifier();
     output << ", ";
     output <<  identifier.db;
     output << ", ";

=== modified file 'drizzled/message/schema.cc'
--- drizzled/message/schema.cc	2010-12-29 20:26:03 +0000
+++ drizzled/message/schema.cc	2011-01-01 01:13:51 +0000
@@ -27,6 +27,8 @@
 #include "drizzled/message/schema.h"
 #include "drizzled/session.h"
 
+#include "drizzled/catalog/local.h"
+
 namespace drizzled {
 namespace message {
 namespace schema {
@@ -43,7 +45,7 @@
 void init(drizzled::message::Schema &arg, const std::string &name_arg)
 {
   arg.set_name(name_arg);
-  arg.set_catalog("local");
+  arg.set_catalog(drizzled::catalog::local()->name());
   arg.mutable_engine()->set_name(std::string("filesystem")); // For the moment we have only one.
   arg.set_creation_timestamp(time(NULL));
   arg.set_update_timestamp(time(NULL));

=== modified file 'drizzled/message/schema_writer.cc'
--- drizzled/message/schema_writer.cc	2010-10-05 08:06:38 +0000
+++ drizzled/message/schema_writer.cc	2011-01-01 01:13:51 +0000
@@ -44,6 +44,7 @@
     file_name= argv[1];
 
   schema.set_name(argv[1]);
+  schema.set_catalog("LOCAL");
   schema.mutable_engine()->set_name("filesystem");
   schema.set_creation_timestamp(time(NULL));
   schema.set_update_timestamp(time(NULL));

=== modified file 'drizzled/message/table.cc'
--- drizzled/message/table.cc	2010-12-29 20:26:03 +0000
+++ drizzled/message/table.cc	2011-01-01 01:13:51 +0000
@@ -23,6 +23,7 @@
 #include "drizzled/message/table.h"
 #include "drizzled/charset_info.h"
 #include "drizzled/global_charset_info.h"
+#include "drizzled/catalog/local.h"
 
 namespace drizzled {
 namespace message {
@@ -61,6 +62,8 @@
 
   arg.mutable_options()->set_collation_id(default_charset_info->number);
   arg.mutable_options()->set_collation(default_charset_info->name);
+
+  arg.set_catalog(drizzled::catalog::local()->name());
 }
 
 void update(drizzled::message::Table &arg)

=== modified file 'drizzled/message/table_writer.cc'
--- drizzled/message/table_writer.cc	2010-12-18 04:43:40 +0000
+++ drizzled/message/table_writer.cc	2011-01-01 01:13:51 +0000
@@ -203,6 +203,7 @@
   message::Table::TableOptions *tableopts;
 
   table->set_name("t1");
+  table->set_catalog("LOCAL");
   table->set_type(message::Table::INTERNAL);
 
   tableopts= table->mutable_options();
@@ -263,7 +264,7 @@
 
   fstream output(vm["table-name"].as<string>().c_str(),
                  ios::out | ios::trunc | ios::binary);
-  if (!table.SerializeToOstream(&output))
+  if (not table.SerializeToOstream(&output))
   {
     cerr << "Failed to write schema." << endl;
     return -1;

=== modified file 'drizzled/plugin/catalog.cc'
--- drizzled/plugin/catalog.cc	2010-12-30 08:27:31 +0000
+++ drizzled/plugin/catalog.cc	2011-01-01 01:13:51 +0000
@@ -22,6 +22,7 @@
 
 #include "drizzled/plugin/catalog.h"
 #include "drizzled/catalog/cache.h"
+#include "drizzled/catalog/local.h"
 #include "drizzled/error.h"
 
 #include <boost/foreach.hpp>
@@ -90,8 +91,7 @@
 
 bool Catalog::drop(const identifier::Catalog &identifier)
 {
-  static drizzled::identifier::Catalog LOCAL_IDENTIFIER("local");
-  if (identifier == LOCAL_IDENTIFIER)
+  if (identifier == drizzled::catalog::local_identifier())
   {
     my_error(drizzled::ER_CATALOG_NO_DROP_LOCAL, MYF(0));
     return false;

=== modified file 'plugin/catalog/engine.h'
--- plugin/catalog/engine.h	2010-12-09 06:12:03 +0000
+++ plugin/catalog/engine.h	2011-01-01 01:13:51 +0000
@@ -40,9 +40,7 @@
 
   bool exist(const drizzled::identifier::Catalog &identifier)
   {
-    static drizzled::identifier::Catalog LOCAL_IDENTIFIER("local");
-
-    if (LOCAL_IDENTIFIER == identifier)
+    if (drizzled::catalog::local_identifier() == identifier)
       return true;
 
     return false;
@@ -50,15 +48,12 @@
 
   void getIdentifiers(drizzled::identifier::Catalog::vector &identifiers)
   {
-    static drizzled::identifier::Catalog LOCAL_IDENTIFIER("local");
-    identifiers.push_back(LOCAL_IDENTIFIER);
+    identifiers.push_back(drizzled::catalog::local_identifier());
   }
 
   bool getMessage(const drizzled::identifier::Catalog &identifier, drizzled::message::catalog::shared_ptr &message)
   {
-    static drizzled::identifier::Catalog LOCAL_IDENTIFIER("local");
-
-    if (LOCAL_IDENTIFIER == identifier)
+    if (drizzled::catalog::local_identifier() == identifier)
     {
       message= drizzled::message::catalog::make_shared(identifier);
 
@@ -72,9 +67,7 @@
 
   bool getInstance(const drizzled::identifier::Catalog &identifier, drizzled::catalog::Instance::shared_ptr &instance)
   {
-    static drizzled::identifier::Catalog LOCAL_IDENTIFIER("local");
-
-    if (LOCAL_IDENTIFIER == identifier)
+    if (drizzled::catalog::local_identifier() == identifier)
     {
       instance=  drizzled::catalog::Instance::create(identifier);
 

=== modified file 'plugin/catalog/tests/r/catalog_cache_table.result'
--- plugin/catalog/tests/r/catalog_cache_table.result	2010-12-02 07:08:17 +0000
+++ plugin/catalog/tests/r/catalog_cache_table.result	2011-01-01 01:13:51 +0000
@@ -1,2 +1,3 @@
 SELECT CATALOG_NAME FROM DATA_DICTIONARY.CATALOG_CACHE;
 CATALOG_NAME
+LOCAL

=== modified file 'plugin/catalog/tests/r/catalogs_table.result'
--- plugin/catalog/tests/r/catalogs_table.result	2010-12-02 07:08:17 +0000
+++ plugin/catalog/tests/r/catalogs_table.result	2011-01-01 01:13:51 +0000
@@ -1,3 +1,3 @@
 SELECT CATALOG_NAME FROM DATA_DICTIONARY.CATALOGS;
 CATALOG_NAME
-local
+LOCAL

=== modified file 'plugin/catalog/tests/r/create.result'
--- plugin/catalog/tests/r/create.result	2010-12-29 20:26:03 +0000
+++ plugin/catalog/tests/r/create.result	2011-01-01 01:13:51 +0000
@@ -22,7 +22,7 @@
 foo1
 foo2
 foo4
-local
+LOCAL
 SELECT DROP_CATALOG("foo1");
 DROP_CATALOG("foo1")
 1

=== modified file 'plugin/information_schema_dictionary/tests/r/key_column_usage.result'
--- plugin/information_schema_dictionary/tests/r/key_column_usage.result	2010-10-06 00:12:36 +0000
+++ plugin/information_schema_dictionary/tests/r/key_column_usage.result	2011-01-01 01:13:51 +0000
@@ -336,40 +336,40 @@
 ) ;
 select * from information_schema.key_column_usage WHERE table_schema="everything" ORDER BY TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME;
 CONSTRAINT_CATALOG	CONSTRAINT_SCHEMA	CONSTRAINT_NAME	TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	COLUMN_NAME	ORDINAL_POSITION
-	everything	PRIMARY		everything	branch	branch_id	1
-	everything	PRIMARY		everything	container	container_id	1
-	everything	PRIMARY		everything	document	document_id	1
-	everything	PRIMARY		everything	genstats_attributes	genstats_attributes_id	1
-	everything	PRIMARY		everything	htmlcode	htmlcode_id	1
-	everything	PRIMARY		everything	htmlpage	htmlpage_id	1
-	everything	PRIMARY		everything	image	image_id	1
-	everything	PRIMARY		everything	javascript	javascript_id	1
-	everything	PRIMARY		everything	knowledge_item	knowledge_item_id	1
-	everything	PRIMARY		everything	links	from_node	1
-	everything	PRIMARY		everything	links	linktype	3
-	everything	PRIMARY		everything	links	to_node	2
-	everything	PRIMARY		everything	mail	mail_id	1
-	everything	PRIMARY		everything	node	node_id	1
-	everything	PRIMARY		everything	nodegroup	nodegroup_id	1
-	everything	PRIMARY		everything	nodegroup	rank	2
-	everything	PRIMARY		everything	nodelet	nodelet_id	1
-	everything	PRIMARY		everything	nodemethod	nodemethod_id	1
-	everything	PRIMARY		everything	nodetype	nodetype_id	1
-	everything	PRIMARY		everything	project	project_id	1
-	everything	PRIMARY		everything	project_document	project_document_id	1
-	everything	PRIMARY		everything	question	question_id	1
-	everything	PRIMARY		everything	question	rank	2
-	everything	PRIMARY		everything	redirects	redirects_id	1
-	everything	PRIMARY		everything	releases	releases_id	1
-	everything	PRIMARY		everything	revision	inside_workspace	2
-	everything	PRIMARY		everything	revision	node_id	1
-	everything	PRIMARY		everything	revision	revision_id	3
-	everything	PRIMARY		everything	setting	setting_id	1
-	everything	PRIMARY		everything	symlink	symlink_id	1
-	everything	PRIMARY		everything	themesetting	themesetting_id	1
-	everything	PRIMARY		everything	typeversion	typeversion_id	1
-	everything	PRIMARY		everything	user	user_id	1
-	everything	PRIMARY		everything	version	version_id	1
-	everything	PRIMARY		everything	weblog	entry_id	1
-	everything	PRIMARY		everything	workspace	workspace_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	branch	branch_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	container	container_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	document	document_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	genstats_attributes	genstats_attributes_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	htmlcode	htmlcode_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	htmlpage	htmlpage_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	image	image_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	javascript	javascript_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	knowledge_item	knowledge_item_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	links	from_node	1
+LOCAL	everything	PRIMARY	LOCAL	everything	links	linktype	3
+LOCAL	everything	PRIMARY	LOCAL	everything	links	to_node	2
+LOCAL	everything	PRIMARY	LOCAL	everything	mail	mail_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	node	node_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	nodegroup	nodegroup_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	nodegroup	rank	2
+LOCAL	everything	PRIMARY	LOCAL	everything	nodelet	nodelet_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	nodemethod	nodemethod_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	nodetype	nodetype_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	project	project_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	project_document	project_document_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	question	question_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	question	rank	2
+LOCAL	everything	PRIMARY	LOCAL	everything	redirects	redirects_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	releases	releases_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	revision	inside_workspace	2
+LOCAL	everything	PRIMARY	LOCAL	everything	revision	node_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	revision	revision_id	3
+LOCAL	everything	PRIMARY	LOCAL	everything	setting	setting_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	symlink	symlink_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	themesetting	themesetting_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	typeversion	typeversion_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	user	user_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	version	version_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	weblog	entry_id	1
+LOCAL	everything	PRIMARY	LOCAL	everything	workspace	workspace_id	1
 drop schema everything;

=== modified file 'plugin/information_schema_dictionary/tests/r/schemata.result'
--- plugin/information_schema_dictionary/tests/r/schemata.result	2010-12-30 08:27:31 +0000
+++ plugin/information_schema_dictionary/tests/r/schemata.result	2011-01-01 01:13:51 +0000
@@ -2,8 +2,8 @@
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	data_dictionary	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-local	test	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 use information_schema;
 show schemas;
 Database
@@ -15,8 +15,8 @@
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	data_dictionary	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-local	test	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 select * from INFORMATION_SCHEMA.SCHEMATA WHERE CATALOG_NAME=NULL;
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 select * from INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_OWNER=NULL;
@@ -37,20 +37,20 @@
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	data_dictionary	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-local	test	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 select * from INFORMATION_SCHEMA.SCHEMATA ORDER BY SCHEMA_NAME,CATALOG_NAME;
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	data_dictionary	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-local	test	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 select * from INFORMATION_SCHEMA.SCHEMATA ORDER BY CATALOG_NAME,SCHEMA_NAME;
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	data_dictionary	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-local	test	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 create schema a;
 create schema b;
 create schema c;
@@ -59,43 +59,43 @@
 create schema aa;
 SELECT * FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME="a";
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
-local	a	NULL	NULL	NULL	NULL
+LOCAL	a	NULL	NULL	NULL	NULL
 SELECT * FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME like "a%";
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
-local	a	NULL	NULL	NULL	NULL
-local	aa	NULL	NULL	NULL	NULL
+LOCAL	a	NULL	NULL	NULL	NULL
+LOCAL	aa	NULL	NULL	NULL	NULL
 SELECT * FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME like "%a";
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	information_schema	NULL	NULL	NULL	NULL
-local	a	NULL	NULL	NULL	NULL
-local	aa	NULL	NULL	NULL	NULL
+LOCAL	a	NULL	NULL	NULL	NULL
+LOCAL	aa	NULL	NULL	NULL	NULL
 SELECT * FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME like "%s";
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
-local	ds	NULL	NULL	NULL	NULL
+LOCAL	ds	NULL	NULL	NULL	NULL
 SELECT * FROM INFORMATION_SCHEMA.SCHEMATA;
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	data_dictionary	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-local	a	NULL	NULL	NULL	NULL
-local	aa	NULL	NULL	NULL	NULL
-local	b	NULL	NULL	NULL	NULL
-local	c	NULL	NULL	NULL	NULL
-local	d	NULL	NULL	NULL	NULL
-local	ds	NULL	NULL	NULL	NULL
-local	test	NULL	NULL	NULL	NULL
+LOCAL	a	NULL	NULL	NULL	NULL
+LOCAL	aa	NULL	NULL	NULL	NULL
+LOCAL	b	NULL	NULL	NULL	NULL
+LOCAL	c	NULL	NULL	NULL	NULL
+LOCAL	d	NULL	NULL	NULL	NULL
+LOCAL	ds	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 SELECT * FROM INFORMATION_SCHEMA.SCHEMATA ORDER BY SCHEMA_NAME;
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
-local	a	NULL	NULL	NULL	NULL
-local	aa	NULL	NULL	NULL	NULL
-local	b	NULL	NULL	NULL	NULL
-local	c	NULL	NULL	NULL	NULL
-local	d	NULL	NULL	NULL	NULL
+LOCAL	a	NULL	NULL	NULL	NULL
+LOCAL	aa	NULL	NULL	NULL	NULL
+LOCAL	b	NULL	NULL	NULL	NULL
+LOCAL	c	NULL	NULL	NULL	NULL
+LOCAL	d	NULL	NULL	NULL	NULL
 	data_dictionary	NULL	NULL	NULL	NULL
-local	ds	NULL	NULL	NULL	NULL
+LOCAL	ds	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-local	test	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 drop schema a;
 drop schema b;
 drop schema c;

=== modified file 'plugin/information_schema_dictionary/tests/r/table_constraints.result'
--- plugin/information_schema_dictionary/tests/r/table_constraints.result	2010-12-12 20:55:48 +0000
+++ plugin/information_schema_dictionary/tests/r/table_constraints.result	2011-01-01 01:13:51 +0000
@@ -336,36 +336,36 @@
 ) ;
 select * from information_schema.TABLE_CONSTRAINTS WHERE table_schema="everything" ORDER BY CONSTRAINT_CATALOG, CONSTRAINT_SCHEMA, CONSTRAINT_NAME;
 CONSTRAINT_CATALOG	CONSTRAINT_SCHEMA	CONSTRAINT_NAME	TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	CONSTRAINT_TYPE	IS_DEFERRABLE	INITIALLY_DEFERRED
-	everything	PRIMARY		everything	branch	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	container	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	document	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	genstats_attributes	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	htmlcode	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	htmlpage	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	image	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	javascript	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	knowledge_item	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	links	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	mail	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	node	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	nodegroup	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	nodelet	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	nodemethod	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	nodetype	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	project	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	project_document	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	question	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	redirects	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	releases	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	revision	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	setting	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	symlink	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	themesetting	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	typeversion	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	user	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	version	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	weblog	PRIMARY KEY	NO	NO
-	everything	PRIMARY		everything	workspace	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	branch	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	container	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	document	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	genstats_attributes	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	htmlcode	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	htmlpage	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	image	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	javascript	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	knowledge_item	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	links	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	mail	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	node	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	nodegroup	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	nodelet	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	nodemethod	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	nodetype	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	project	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	project_document	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	question	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	redirects	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	releases	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	revision	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	setting	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	symlink	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	themesetting	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	typeversion	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	user	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	version	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	weblog	PRIMARY KEY	NO	NO
+LOCAL	everything	PRIMARY	LOCAL	everything	workspace	PRIMARY KEY	NO	NO
 drop schema everything;
 create schema slashdot;
 use slashdot;
@@ -3290,282 +3290,282 @@
 );
 select * from information_schema.TABLE_CONSTRAINTS WHERE table_schema="slashdot" ORDER BY CONSTRAINT_CATALOG, CONSTRAINT_SCHEMA, CONSTRAINT_NAME;
 CONSTRAINT_CATALOG	CONSTRAINT_SCHEMA	CONSTRAINT_NAME	TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	CONSTRAINT_TYPE	IS_DEFERRABLE	INITIALLY_DEFERRED
-	slashdot	PRIMARY		slashdot	abusers	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	accesslog_build_unique_uid	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	accesslog_temp_host_addr	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	achievements	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	ajax_ops	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	al2	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	al2_log	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	al2_log_comments	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	al2_types	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	anniversary	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	authors_cache	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	auto_poll	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	backup_blocks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	badge_ids	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	blobs	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	blocks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	bookmark_feeds	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	bookmarks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	bpn_sources	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	classes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	clout_types	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	code_param	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	comment_log	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	comment_promote_log	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	comment_text	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	commentmodes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	comments	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	content_filters	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	css	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	css_type	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	dateformats	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	daypass_available	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	daypass_confcodes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	daypass_keys	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	dbs	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	dbs_readerstatus_queries	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	discussion_kinds	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	discussions	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	dst	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	dynamic_blocks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	dynamic_user_blocks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	farm_globjid	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	farm_ipid	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	farm_uid	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	file_queue	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_ogaspt	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_section	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_section_settings	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_setting_log	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_skin_volume	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_tab	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_text	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_update_log	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_update_log_temp	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_view	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	firehose_view_settings	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	formkeys	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	globj_adminnotes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	globj_types	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	globj_urls	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	globjs	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	globjs_viewed	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	globjs_viewed_archived	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	hooks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	humanconf	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	humanconf_pool	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	humanconf_questions	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	journal_themes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	journal_transfer	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	journals	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	journals_text	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	links	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	links_for_stories	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	memcached_stats	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	menus	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	message_codes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	message_deliverymodes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	message_drop	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	message_web	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	message_web_text	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	metamodlog	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	microbin	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	misc_user_opts	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	moderatorlog	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	modreasons	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	open_proxies	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	people	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	pollanswers	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	pollquestions	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	preview	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	preview_param	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	projects	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	related_links	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	related_stories	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	remarks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	reskey_failures	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	reskey_resource_checks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	reskey_resources	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	reskey_sessions	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	reskeys	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	rss_raw	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	search_index_dump	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	section_extras	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	section_subsections	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	section_topics	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	sections	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	sections_contained	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	sessions	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	shill_ids	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	signoff	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	site_info	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	skins	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	slashd_status	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	soap_methods	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	spamarmors	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	sphinx_index	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	static_files	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	stats_daily	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	stories	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	stories_media	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	story_dirty	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	story_files	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	story_param	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	story_render_dirty	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	story_text	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	string_param	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	submission_param	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	submissions	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	submissions_notes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	subscribe_payments	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	subsections	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	surv_answers	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	surv_answers_params	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	surv_choices	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	surv_questions	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	surv_surveys	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	surv_surveys_params	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tagbox_metamod_history	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tagboxes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tagboxlog_feeder	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tagboxlog_feeder_archived	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tagcommand_adminlog	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tagname_cache	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tagnames	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags_dayofweek	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags_deactivated	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags_hourofday	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags_peerclout	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags_searched	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags_udc	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tags_userchange	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	templates	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	topic_nexus	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	topic_nexus_dirty	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	topic_nexus_extras	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	topic_param	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	topics	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	topics_changetid	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	tzcodes	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	uncommonstorywords	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	urls	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	user_achievement_streaks	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	user_achievements	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_acl	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_clout	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_comments	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_hits	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_index	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_info	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_logtokens	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_messages	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_openid	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_openid_reskeys	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_param	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	users_prefs	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	vars	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	wow_char_armorylog	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	wow_char_data	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	wow_char_types	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	wow_chars	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	wow_guilds	PRIMARY KEY	NO	NO
-	slashdot	PRIMARY		slashdot	wow_realms	PRIMARY KEY	NO	NO
-	slashdot	achievement		slashdot	achievements	UNIQUE	NO	NO
-	slashdot	achievement		slashdot	user_achievement_streaks	UNIQUE	NO	NO
-	slashdot	achievement		slashdot	user_achievements	UNIQUE	NO	NO
-	slashdot	bid		slashdot	blocks	UNIQUE	NO	NO
-	slashdot	bitpos		slashdot	al2_types	UNIQUE	NO	NO
-	slashdot	charid_wcdtype		slashdot	wow_char_data	UNIQUE	NO	NO
-	slashdot	child_and_parent		slashdot	topic_parents	UNIQUE	NO	NO
-	slashdot	class_key		slashdot	classes	UNIQUE	NO	NO
-	slashdot	clid_pref_syn		slashdot	tagnames_synonyms_chosen	UNIQUE	NO	NO
-	slashdot	clid_syn_sim		slashdot	tagnames_similarity_rendered	UNIQUE	NO	NO
-	slashdot	code_key		slashdot	code_param	UNIQUE	NO	NO
-	slashdot	code_key		slashdot	string_param	UNIQUE	NO	NO
-	slashdot	code_key		slashdot	subsections	UNIQUE	NO	NO
-	slashdot	code_key		slashdot	users_messages	UNIQUE	NO	NO
-	slashdot	container		slashdot	sections_contained	UNIQUE	NO	NO
-	slashdot	country_realm		slashdot	wow_realms	UNIQUE	NO	NO
-	slashdot	day_key_pair		slashdot	stats_daily	UNIQUE	NO	NO
-	slashdot	daypasskey		slashdot	daypass_keys	UNIQUE	NO	NO
-	slashdot	degree_of_separation		slashdot	people	UNIQUE	NO	NO
-	slashdot	discussion_id		slashdot	users_comments_read_log	UNIQUE	NO	NO
-	slashdot	extra		slashdot	section_extras	UNIQUE	NO	NO
-	slashdot	formkey		slashdot	humanconf	UNIQUE	NO	NO
-	slashdot	globjid		slashdot	firehose	UNIQUE	NO	NO
-	slashdot	globjid_secsin		slashdot	firehose_history	UNIQUE	NO	NO
-	slashdot	globjid_uid		slashdot	globjs_viewed	UNIQUE	NO	NO
-	slashdot	globjid_uid		slashdot	globjs_viewed_archived	UNIQUE	NO	NO
-	slashdot	globjid_url_id		slashdot	globj_urls	UNIQUE	NO	NO
-	slashdot	hook_param		slashdot	hooks	UNIQUE	NO	NO
-	slashdot	host_addr		slashdot	accesslog_temp_host_addr	UNIQUE	NO	NO
-	slashdot	id_tid		slashdot	firehose_topics_rendered	UNIQUE	NO	NO
-	slashdot	idx_name		slashdot	wow_guilds	UNIQUE	NO	NO
-	slashdot	idx_uid_name		slashdot	dynamic_user_blocks	UNIQUE	NO	NO
-	slashdot	keyword		slashdot	topics	UNIQUE	NO	NO
-	slashdot	maintable		slashdot	globj_types	UNIQUE	NO	NO
-	slashdot	name		slashdot	al2_types	UNIQUE	NO	NO
-	slashdot	name		slashdot	clout_types	UNIQUE	NO	NO
-	slashdot	name		slashdot	discussion_kinds	UNIQUE	NO	NO
-	slashdot	name		slashdot	dynamic_user_blocks	UNIQUE	NO	NO
-	slashdot	name		slashdot	journal_themes	UNIQUE	NO	NO
-	slashdot	name		slashdot	skins	UNIQUE	NO	NO
-	slashdot	name		slashdot	sphinx_index	UNIQUE	NO	NO
-	slashdot	name		slashdot	tagboxes	UNIQUE	NO	NO
-	slashdot	name		slashdot	wow_char_types	UNIQUE	NO	NO
-	slashdot	name_rkrid		slashdot	reskey_vars	UNIQUE	NO	NO
-	slashdot	op		slashdot	ajax_ops	UNIQUE	NO	NO
-	slashdot	openid_url		slashdot	users_openid	UNIQUE	NO	NO
-	slashdot	page_labels_un		slashdot	menus	UNIQUE	NO	NO
-	slashdot	realm_name		slashdot	wow_chars	UNIQUE	NO	NO
-	slashdot	reskey		slashdot	reskeys	UNIQUE	NO	NO
-	slashdot	reskey_name		slashdot	reskey_sessions	UNIQUE	NO	NO
-	slashdot	rkrid_name		slashdot	reskey_resource_checks	UNIQUE	NO	NO
-	slashdot	section		slashdot	sections	UNIQUE	NO	NO
-	slashdot	sid		slashdot	stories	UNIQUE	NO	NO
-	slashdot	signature		slashdot	submissions	UNIQUE	NO	NO
-	slashdot	site		slashdot	xsite_auth_log	UNIQUE	NO	NO
-	slashdot	site_keys		slashdot	site_info	UNIQUE	NO	NO
-	slashdot	skid_day_name		slashdot	stats_daily	UNIQUE	NO	NO
-	slashdot	skid_name		slashdot	skin_colors	UNIQUE	NO	NO
-	slashdot	soap_method		slashdot	soap_methods	UNIQUE	NO	NO
-	slashdot	src_completion		slashdot	sphinx_counter	UNIQUE	NO	NO
-	slashdot	src_completion		slashdot	sphinx_counter_archived	UNIQUE	NO	NO
-	slashdot	status		slashdot	microbin	UNIQUE	NO	NO
-	slashdot	story_key		slashdot	story_param	UNIQUE	NO	NO
-	slashdot	story_topic		slashdot	story_topics_chosen	UNIQUE	NO	NO
-	slashdot	story_topic		slashdot	story_topics_rendered	UNIQUE	NO	NO
-	slashdot	submission_key		slashdot	preview_param	UNIQUE	NO	NO
-	slashdot	submission_key		slashdot	submission_param	UNIQUE	NO	NO
-	slashdot	svsid		slashdot	surv_surveys	UNIQUE	NO	NO
-	slashdot	tag_name		slashdot	tag_params	UNIQUE	NO	NO
-	slashdot	tagname		slashdot	tagname_cache	UNIQUE	NO	NO
-	slashdot	tagname		slashdot	tagnames	UNIQUE	NO	NO
-	slashdot	tagname_name		slashdot	tagname_params	UNIQUE	NO	NO
-	slashdot	target		slashdot	globjs	UNIQUE	NO	NO
-	slashdot	tid_keyword		slashdot	topic_nexus_extras	UNIQUE	NO	NO
-	slashdot	topic_key		slashdot	topic_param	UNIQUE	NO	NO
-	slashdot	transaction_id		slashdot	subscribe_payments	UNIQUE	NO	NO
-	slashdot	true_template		slashdot	templates	UNIQUE	NO	NO
-	slashdot	ts		slashdot	reskey_hourlysalt	UNIQUE	NO	NO
-	slashdot	type_vu		slashdot	dbs	UNIQUE	NO	NO
-	slashdot	uber_signature		slashdot	rss_raw	UNIQUE	NO	NO
-	slashdot	uid		slashdot	sessions	UNIQUE	NO	NO
-	slashdot	uid_clid		slashdot	tags_peerclout	UNIQUE	NO	NO
-	slashdot	uid_clid		slashdot	users_clout	UNIQUE	NO	NO
-	slashdot	uid_fsid		slashdot	firehose_section_settings	UNIQUE	NO	NO
-	slashdot	uid_globjid		slashdot	firehose_tfh	UNIQUE	NO	NO
-	slashdot	uid_globjid		slashdot	firehose_tfhp	UNIQUE	NO	NO
-	slashdot	uid_key		slashdot	users_acl	UNIQUE	NO	NO
-	slashdot	uid_key		slashdot	users_param	UNIQUE	NO	NO
-	slashdot	uid_locationid_temp_public		slashdot	users_logtokens	UNIQUE	NO	NO
-	slashdot	uid_tabname		slashdot	firehose_tab	UNIQUE	NO	NO
-	slashdot	unixname		slashdot	projects	UNIQUE	NO	NO
-	slashdot	url_digest		slashdot	urls	UNIQUE	NO	NO
-	slashdot	url_id_uid		slashdot	bookmarks	UNIQUE	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	abusers	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	accesslog_build_unique_uid	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	accesslog_temp_host_addr	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	achievements	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	ajax_ops	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	al2	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	al2_log	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	al2_log_comments	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	al2_types	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	anniversary	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	authors_cache	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	auto_poll	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	backup_blocks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	badge_ids	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	blobs	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	blocks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	bookmark_feeds	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	bookmarks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	bpn_sources	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	classes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	clout_types	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	code_param	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	comment_log	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	comment_promote_log	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	comment_text	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	commentmodes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	comments	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	content_filters	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	css	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	css_type	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	dateformats	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	daypass_available	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	daypass_confcodes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	daypass_keys	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	dbs	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	dbs_readerstatus_queries	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	discussion_kinds	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	discussions	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	dst	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	dynamic_blocks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	dynamic_user_blocks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	farm_globjid	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	farm_ipid	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	farm_uid	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	file_queue	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_ogaspt	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_section	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_section_settings	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_setting_log	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_skin_volume	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_tab	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_text	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_update_log	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_update_log_temp	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_view	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	firehose_view_settings	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	formkeys	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	globj_adminnotes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	globj_types	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	globj_urls	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	globjs	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	globjs_viewed	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	globjs_viewed_archived	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	hooks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	humanconf	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	humanconf_pool	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	humanconf_questions	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	journal_themes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	journal_transfer	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	journals	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	journals_text	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	links	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	links_for_stories	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	memcached_stats	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	menus	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	message_codes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	message_deliverymodes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	message_drop	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	message_web	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	message_web_text	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	metamodlog	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	microbin	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	misc_user_opts	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	moderatorlog	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	modreasons	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	open_proxies	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	people	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	pollanswers	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	pollquestions	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	preview	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	preview_param	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	projects	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	related_links	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	related_stories	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	remarks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	reskey_failures	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	reskey_resource_checks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	reskey_resources	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	reskey_sessions	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	reskeys	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	rss_raw	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	search_index_dump	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	section_extras	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	section_subsections	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	section_topics	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	sections	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	sections_contained	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	sessions	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	shill_ids	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	signoff	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	site_info	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	skins	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	slashd_status	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	soap_methods	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	spamarmors	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	sphinx_index	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	static_files	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	stats_daily	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	stories	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	stories_media	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	story_dirty	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	story_files	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	story_param	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	story_render_dirty	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	story_text	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	string_param	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	submission_param	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	submissions	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	submissions_notes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	subscribe_payments	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	subsections	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	surv_answers	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	surv_answers_params	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	surv_choices	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	surv_questions	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	surv_surveys	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	surv_surveys_params	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tagbox_metamod_history	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tagboxes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tagboxlog_feeder	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tagboxlog_feeder_archived	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tagcommand_adminlog	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tagname_cache	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tagnames	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags_dayofweek	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags_deactivated	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags_hourofday	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags_peerclout	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags_searched	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags_udc	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tags_userchange	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	templates	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	topic_nexus	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	topic_nexus_dirty	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	topic_nexus_extras	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	topic_param	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	topics	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	topics_changetid	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	tzcodes	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	uncommonstorywords	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	urls	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	user_achievement_streaks	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	user_achievements	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_acl	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_clout	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_comments	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_hits	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_index	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_info	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_logtokens	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_messages	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_openid	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_openid_reskeys	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_param	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	users_prefs	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	vars	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	wow_char_armorylog	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	wow_char_data	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	wow_char_types	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	wow_chars	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	wow_guilds	PRIMARY KEY	NO	NO
+LOCAL	slashdot	PRIMARY	LOCAL	slashdot	wow_realms	PRIMARY KEY	NO	NO
+LOCAL	slashdot	achievement	LOCAL	slashdot	achievements	UNIQUE	NO	NO
+LOCAL	slashdot	achievement	LOCAL	slashdot	user_achievement_streaks	UNIQUE	NO	NO
+LOCAL	slashdot	achievement	LOCAL	slashdot	user_achievements	UNIQUE	NO	NO
+LOCAL	slashdot	bid	LOCAL	slashdot	blocks	UNIQUE	NO	NO
+LOCAL	slashdot	bitpos	LOCAL	slashdot	al2_types	UNIQUE	NO	NO
+LOCAL	slashdot	charid_wcdtype	LOCAL	slashdot	wow_char_data	UNIQUE	NO	NO
+LOCAL	slashdot	child_and_parent	LOCAL	slashdot	topic_parents	UNIQUE	NO	NO
+LOCAL	slashdot	class_key	LOCAL	slashdot	classes	UNIQUE	NO	NO
+LOCAL	slashdot	clid_pref_syn	LOCAL	slashdot	tagnames_synonyms_chosen	UNIQUE	NO	NO
+LOCAL	slashdot	clid_syn_sim	LOCAL	slashdot	tagnames_similarity_rendered	UNIQUE	NO	NO
+LOCAL	slashdot	code_key	LOCAL	slashdot	code_param	UNIQUE	NO	NO
+LOCAL	slashdot	code_key	LOCAL	slashdot	string_param	UNIQUE	NO	NO
+LOCAL	slashdot	code_key	LOCAL	slashdot	subsections	UNIQUE	NO	NO
+LOCAL	slashdot	code_key	LOCAL	slashdot	users_messages	UNIQUE	NO	NO
+LOCAL	slashdot	container	LOCAL	slashdot	sections_contained	UNIQUE	NO	NO
+LOCAL	slashdot	country_realm	LOCAL	slashdot	wow_realms	UNIQUE	NO	NO
+LOCAL	slashdot	day_key_pair	LOCAL	slashdot	stats_daily	UNIQUE	NO	NO
+LOCAL	slashdot	daypasskey	LOCAL	slashdot	daypass_keys	UNIQUE	NO	NO
+LOCAL	slashdot	degree_of_separation	LOCAL	slashdot	people	UNIQUE	NO	NO
+LOCAL	slashdot	discussion_id	LOCAL	slashdot	users_comments_read_log	UNIQUE	NO	NO
+LOCAL	slashdot	extra	LOCAL	slashdot	section_extras	UNIQUE	NO	NO
+LOCAL	slashdot	formkey	LOCAL	slashdot	humanconf	UNIQUE	NO	NO
+LOCAL	slashdot	globjid	LOCAL	slashdot	firehose	UNIQUE	NO	NO
+LOCAL	slashdot	globjid_secsin	LOCAL	slashdot	firehose_history	UNIQUE	NO	NO
+LOCAL	slashdot	globjid_uid	LOCAL	slashdot	globjs_viewed	UNIQUE	NO	NO
+LOCAL	slashdot	globjid_uid	LOCAL	slashdot	globjs_viewed_archived	UNIQUE	NO	NO
+LOCAL	slashdot	globjid_url_id	LOCAL	slashdot	globj_urls	UNIQUE	NO	NO
+LOCAL	slashdot	hook_param	LOCAL	slashdot	hooks	UNIQUE	NO	NO
+LOCAL	slashdot	host_addr	LOCAL	slashdot	accesslog_temp_host_addr	UNIQUE	NO	NO
+LOCAL	slashdot	id_tid	LOCAL	slashdot	firehose_topics_rendered	UNIQUE	NO	NO
+LOCAL	slashdot	idx_name	LOCAL	slashdot	wow_guilds	UNIQUE	NO	NO
+LOCAL	slashdot	idx_uid_name	LOCAL	slashdot	dynamic_user_blocks	UNIQUE	NO	NO
+LOCAL	slashdot	keyword	LOCAL	slashdot	topics	UNIQUE	NO	NO
+LOCAL	slashdot	maintable	LOCAL	slashdot	globj_types	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	al2_types	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	clout_types	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	discussion_kinds	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	dynamic_user_blocks	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	journal_themes	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	skins	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	sphinx_index	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	tagboxes	UNIQUE	NO	NO
+LOCAL	slashdot	name	LOCAL	slashdot	wow_char_types	UNIQUE	NO	NO
+LOCAL	slashdot	name_rkrid	LOCAL	slashdot	reskey_vars	UNIQUE	NO	NO
+LOCAL	slashdot	op	LOCAL	slashdot	ajax_ops	UNIQUE	NO	NO
+LOCAL	slashdot	openid_url	LOCAL	slashdot	users_openid	UNIQUE	NO	NO
+LOCAL	slashdot	page_labels_un	LOCAL	slashdot	menus	UNIQUE	NO	NO
+LOCAL	slashdot	realm_name	LOCAL	slashdot	wow_chars	UNIQUE	NO	NO
+LOCAL	slashdot	reskey	LOCAL	slashdot	reskeys	UNIQUE	NO	NO
+LOCAL	slashdot	reskey_name	LOCAL	slashdot	reskey_sessions	UNIQUE	NO	NO
+LOCAL	slashdot	rkrid_name	LOCAL	slashdot	reskey_resource_checks	UNIQUE	NO	NO
+LOCAL	slashdot	section	LOCAL	slashdot	sections	UNIQUE	NO	NO
+LOCAL	slashdot	sid	LOCAL	slashdot	stories	UNIQUE	NO	NO
+LOCAL	slashdot	signature	LOCAL	slashdot	submissions	UNIQUE	NO	NO
+LOCAL	slashdot	site	LOCAL	slashdot	xsite_auth_log	UNIQUE	NO	NO
+LOCAL	slashdot	site_keys	LOCAL	slashdot	site_info	UNIQUE	NO	NO
+LOCAL	slashdot	skid_day_name	LOCAL	slashdot	stats_daily	UNIQUE	NO	NO
+LOCAL	slashdot	skid_name	LOCAL	slashdot	skin_colors	UNIQUE	NO	NO
+LOCAL	slashdot	soap_method	LOCAL	slashdot	soap_methods	UNIQUE	NO	NO
+LOCAL	slashdot	src_completion	LOCAL	slashdot	sphinx_counter	UNIQUE	NO	NO
+LOCAL	slashdot	src_completion	LOCAL	slashdot	sphinx_counter_archived	UNIQUE	NO	NO
+LOCAL	slashdot	status	LOCAL	slashdot	microbin	UNIQUE	NO	NO
+LOCAL	slashdot	story_key	LOCAL	slashdot	story_param	UNIQUE	NO	NO
+LOCAL	slashdot	story_topic	LOCAL	slashdot	story_topics_chosen	UNIQUE	NO	NO
+LOCAL	slashdot	story_topic	LOCAL	slashdot	story_topics_rendered	UNIQUE	NO	NO
+LOCAL	slashdot	submission_key	LOCAL	slashdot	preview_param	UNIQUE	NO	NO
+LOCAL	slashdot	submission_key	LOCAL	slashdot	submission_param	UNIQUE	NO	NO
+LOCAL	slashdot	svsid	LOCAL	slashdot	surv_surveys	UNIQUE	NO	NO
+LOCAL	slashdot	tag_name	LOCAL	slashdot	tag_params	UNIQUE	NO	NO
+LOCAL	slashdot	tagname	LOCAL	slashdot	tagname_cache	UNIQUE	NO	NO
+LOCAL	slashdot	tagname	LOCAL	slashdot	tagnames	UNIQUE	NO	NO
+LOCAL	slashdot	tagname_name	LOCAL	slashdot	tagname_params	UNIQUE	NO	NO
+LOCAL	slashdot	target	LOCAL	slashdot	globjs	UNIQUE	NO	NO
+LOCAL	slashdot	tid_keyword	LOCAL	slashdot	topic_nexus_extras	UNIQUE	NO	NO
+LOCAL	slashdot	topic_key	LOCAL	slashdot	topic_param	UNIQUE	NO	NO
+LOCAL	slashdot	transaction_id	LOCAL	slashdot	subscribe_payments	UNIQUE	NO	NO
+LOCAL	slashdot	true_template	LOCAL	slashdot	templates	UNIQUE	NO	NO
+LOCAL	slashdot	ts	LOCAL	slashdot	reskey_hourlysalt	UNIQUE	NO	NO
+LOCAL	slashdot	type_vu	LOCAL	slashdot	dbs	UNIQUE	NO	NO
+LOCAL	slashdot	uber_signature	LOCAL	slashdot	rss_raw	UNIQUE	NO	NO
+LOCAL	slashdot	uid	LOCAL	slashdot	sessions	UNIQUE	NO	NO
+LOCAL	slashdot	uid_clid	LOCAL	slashdot	tags_peerclout	UNIQUE	NO	NO
+LOCAL	slashdot	uid_clid	LOCAL	slashdot	users_clout	UNIQUE	NO	NO
+LOCAL	slashdot	uid_fsid	LOCAL	slashdot	firehose_section_settings	UNIQUE	NO	NO
+LOCAL	slashdot	uid_globjid	LOCAL	slashdot	firehose_tfh	UNIQUE	NO	NO
+LOCAL	slashdot	uid_globjid	LOCAL	slashdot	firehose_tfhp	UNIQUE	NO	NO
+LOCAL	slashdot	uid_key	LOCAL	slashdot	users_acl	UNIQUE	NO	NO
+LOCAL	slashdot	uid_key	LOCAL	slashdot	users_param	UNIQUE	NO	NO
+LOCAL	slashdot	uid_locationid_temp_public	LOCAL	slashdot	users_logtokens	UNIQUE	NO	NO
+LOCAL	slashdot	uid_tabname	LOCAL	slashdot	firehose_tab	UNIQUE	NO	NO
+LOCAL	slashdot	unixname	LOCAL	slashdot	projects	UNIQUE	NO	NO
+LOCAL	slashdot	url_digest	LOCAL	slashdot	urls	UNIQUE	NO	NO
+LOCAL	slashdot	url_id_uid	LOCAL	slashdot	bookmarks	UNIQUE	NO	NO
 drop schema slashdot;

=== modified file 'plugin/information_schema_dictionary/tests/r/tables.result'
--- plugin/information_schema_dictionary/tests/r/tables.result	2010-12-29 20:26:03 +0000
+++ plugin/information_schema_dictionary/tests/r/tables.result	2011-01-01 01:13:51 +0000
@@ -2,8 +2,8 @@
 CATALOG_NAME	SCHEMA_NAME	SCHEMA_OWNER	DEFAULT_CHARACTER_SET_CATALOG	DEFAULT_CHARACTER_SET_SCHEMA	DEFAULT_CHARACTER_SET_NAME
 	data_dictionary	NULL	NULL	NULL	NULL
 	information_schema	NULL	NULL	NULL	NULL
-	mysql	NULL	NULL	NULL	NULL
-	test	NULL	NULL	NULL	NULL
+LOCAL	mysql	NULL	NULL	NULL	NULL
+LOCAL	test	NULL	NULL	NULL	NULL
 select * from INFORMATION_SCHEMA.TABLES;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
 LOCAL	DATA_DICTIONARY	CATALOGS	VIEW

=== modified file 'plugin/transaction_log/tests/r/bulk_commit.result'
--- plugin/transaction_log/tests/r/bulk_commit.result	2010-12-07 21:25:12 +0000
+++ plugin/transaction_log/tests/r/bulk_commit.result	2011-01-01 01:13:51 +0000
@@ -72,6 +72,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }

=== modified file 'plugin/transaction_log/tests/r/bulk_rollback.result'
--- plugin/transaction_log/tests/r/bulk_rollback.result	2010-12-07 21:25:12 +0000
+++ plugin/transaction_log/tests/r/bulk_rollback.result	2011-01-01 01:13:51 +0000
@@ -70,6 +70,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }

=== modified file 'plugin/transaction_log/tests/r/ddl_transaction_id.result'
--- plugin/transaction_log/tests/r/ddl_transaction_id.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/ddl_transaction_id.result	2011-01-01 01:13:51 +0000
@@ -104,6 +104,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }

=== modified file 'plugin/transaction_log/tests/r/information_schema.result'
--- plugin/transaction_log/tests/r/information_schema.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/information_schema.result	2011-01-01 01:13:51 +0000
@@ -98,6 +98,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }

=== modified file 'plugin/transaction_log/tests/r/transaction_log_alter.result'
--- plugin/transaction_log/tests/r/transaction_log_alter.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/transaction_log_alter.result	2011-01-01 01:13:51 +0000
@@ -115,7 +115,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
-      catalog: ""
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -210,7 +210,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
-      catalog: ""
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -370,6 +370,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -620,6 +621,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -903,6 +905,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -983,6 +986,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1229,6 +1233,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1370,6 +1375,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }

=== modified file 'plugin/transaction_log/tests/r/transaction_log_create.result'
--- plugin/transaction_log/tests/r/transaction_log_create.result	2010-12-23 18:45:30 +0000
+++ plugin/transaction_log/tests/r/transaction_log_create.result	2011-01-01 01:13:51 +0000
@@ -58,6 +58,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -181,6 +182,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -267,6 +269,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -377,6 +380,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -480,6 +484,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -608,6 +613,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -733,6 +739,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -805,6 +812,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -874,6 +882,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -965,6 +974,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1062,6 +1072,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1154,6 +1165,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1240,7 +1252,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
-      catalog: ""
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1355,6 +1367,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1450,6 +1463,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1544,6 +1558,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -1876,6 +1891,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }
@@ -2032,6 +2048,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
+      catalog: "LOCAL"
       
       version: 1
     }

=== modified file 'plugin/transaction_log/tests/r/transaction_log_schema.result'
--- plugin/transaction_log/tests/r/transaction_log_schema.result	2010-12-29 21:23:43 +0000
+++ plugin/transaction_log/tests/r/transaction_log_schema.result	2011-01-01 01:13:51 +0000
@@ -30,7 +30,7 @@
       engine {
         name: "filesystem"
       }
-      catalog: "local"
+      catalog: "LOCAL"
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
       
@@ -253,7 +253,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
-      catalog: ""
+      catalog: "LOCAL"
       
       version: 1
     }

=== modified file 'plugin/transaction_log/tests/r/transaction_log_transaction.result'
--- plugin/transaction_log/tests/r/transaction_log_transaction.result	2010-12-21 20:47:29 +0000
+++ plugin/transaction_log/tests/r/transaction_log_transaction.result	2011-01-01 01:13:51 +0000
@@ -653,7 +653,7 @@
       }
       CREATE_TIMESTAMP
       UPDATE_TIMESTAMP
-      catalog: ""
+      catalog: "LOCAL"
       
       version: 1
     }

